@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 use std::{
+    cmp::Ordering,
     collections::{HashMap, HashSet},
     iter::FusedIterator,
     path::Path,
@@ -11,7 +12,7 @@ use std::{
 use anyhow::Result;
 use assorted_debian_utils::{
     architectures::Architecture,
-    archive::{Codename, Extension, Suite, SuiteOrCodename, WithExtension},
+    archive::{Extension, Suite, SuiteOrCodename, WithExtension},
     package::{PackageName, VersionedPackage},
     rfc822_like,
     version::PackageVersion,
@@ -30,7 +31,7 @@ use crate::{
         Cache, CacheEntries, default_progress_style, default_progress_template, source_skip_binnmu,
     },
     source_packages::{self, SourcePackages},
-    udd_bugs::{UDDBugs, load_bugs_from_reader},
+    udd_bugs::UDDBugs,
     utils::execute_wb_commands,
 };
 
@@ -65,13 +66,13 @@ struct CombinedOutdatedPackage {
 }
 
 impl PartialOrd for CombinedOutdatedPackage {
-    fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
         Some(self.cmp(other))
     }
 }
 
 impl Ord for CombinedOutdatedPackage {
-    fn cmp(&self, other: &Self) -> std::cmp::Ordering {
+    fn cmp(&self, other: &Self) -> Ordering {
         self.source.cmp(&other.source)
     }
 }
@@ -143,7 +144,7 @@ impl Iterator for BinaryPackageParser<'_> {
                 continue;
             };
 
-            let (source_package, version) = binary_package.package.name_and_version();
+            let source_package = binary_package.package.source_package();
 
             // remove trailing spaces found in X-Cargo-Built-Using
             let built_using = built_using.strip_suffix(' ').unwrap_or(built_using);
@@ -163,40 +164,36 @@ impl Iterator for BinaryPackageParser<'_> {
                     split
                 })
                 .filter(|source| {
-                    if let Some(max_version) = self.sources.version(&source.package) {
-                        source.version < *max_version
-                    } else {
-                        // This can happen when considering packages with
-                        // Static-Built-Using, but never with Built-Using. Let's
-                        // rebuild those packages in any case.
-                        trace!(
-                            "Package '{}' refers to non-existing source package '{}'.",
-                            binary_package.package.package, source.package
-                        );
-                        true
-                    }
+                    self.sources
+                        .version(&source.package)
+                        .map(|current_version| source.version < *current_version)
+                        .unwrap_or_else(|| {
+                            // This can happen with Static-Built-Using, but never with Built-Using.
+                            trace!(
+                                "Package '{}' refers to non-existing source package '{}'.",
+                                binary_package.package.package, source.package
+                            );
+                            true
+                        })
                 })
                 .collect();
             // all packages in Built-Using are up to date
             if built_using.is_empty() {
                 trace!(
                     "Skipping {}: all dependencies in {} are up-to-date.",
-                    source_package, self.field
+                    source_package.package, self.field
                 );
                 continue;
             }
 
             // if the package builds any MA: same packages, schedule binNMUs with ANY
-            let architecture = if self.sources.is_ma_same(&source_package) {
+            let architecture = if self.sources.is_ma_same(&source_package.package) {
                 WBArchitecture::Any
             } else {
                 WBArchitecture::Architecture(binary_package.architecture)
             };
             return Some(OutdatedSourcePackage {
-                source: VersionedPackage {
-                    package: source_package.clone(),
-                    version: version.without_binnmu_version(),
-                },
+                source: source_package,
                 built_using,
                 architecture,
             });
@@ -227,13 +224,6 @@ impl<'a> NMUOutdatedBuiltUsing<'a> {
         }
     }
 
-    fn load_bugs(&self, codename: Codename) -> Result<UDDBugs> {
-        load_bugs_from_reader(
-            self.cache
-                .get_cache_bufreader(format!("udd-ftbfs-bugs-{codename}.yaml"))?,
-        )
-    }
-
     /// Load source packages from multiple suites with the highest version
     fn load_sources_for_suites(&self, suites: &[SuiteOrCodename]) -> Result<SourcePackages> {
         let paths: Result<Vec<_>> = suites
@@ -253,11 +243,13 @@ impl<'a> NMUOutdatedBuiltUsing<'a> {
         field: Field,
         suite: SuiteOrCodename,
     ) -> Result<Vec<CombinedOutdatedPackage>> {
-        let ftbfs_bugs = self.load_bugs(suite.into())?;
+        let ftbfs_bugs = UDDBugs::load_for_codename(self.cache, suite)?;
         let source_packages = self.load_sources_for_suites(&self.expand_suite_for_sources())?;
+
+        // collect outdated binary packages
         let mut packages = HashSet::new();
         for suite in self.expand_suite_for_binaries() {
-            let converted_suite: Suite = suite.into();
+            let converted_suite = suite.into();
             for path in self.cache.get_package_paths(suite, false)? {
                 for OutdatedSourcePackage {
                     source,
@@ -265,6 +257,15 @@ impl<'a> NMUOutdatedBuiltUsing<'a> {
                     architecture,
                 } in BinaryPackageParser::new(field, &source_packages, path)?
                 {
+                    // skip some packages that make no sense to binNMU
+                    if source_skip_binnmu(source.package.as_ref()) {
+                        debug!(
+                            "Skipping {}: signed or d-i package or otherwise not binNMU-able",
+                            source.package
+                        );
+                        continue;
+                    }
+
                     packages.extend(dependencies.into_iter().map(|outdated_dependency| {
                         OutdatedPackage {
                             source: source.clone(),
@@ -277,23 +278,10 @@ impl<'a> NMUOutdatedBuiltUsing<'a> {
             }
         }
 
-        let mut result = HashMap::<
-            (PackageName, Suite, WBArchitecture),
-            HashSet<(PackageVersion, VersionedPackage)>,
-        >::new();
+        let mut result = HashMap::<_, HashSet<(PackageVersion, VersionedPackage)>>::new();
         for outdated_package in packages {
-            // skip some packages that make no sense to binNMU
-            if source_skip_binnmu(outdated_package.source.package.as_ref()) {
-                debug!(
-                    "Skipping {}: signed or d-i package",
-                    outdated_package.source.package
-                );
-                continue;
-            }
-
             // check if package FTBFS
-            if let Some(bugs) = ftbfs_bugs.bugs_for_source(outdated_package.source.package.as_ref())
-            {
+            if let Some(bugs) = ftbfs_bugs.bugs_for_source(&outdated_package.source.package) {
                 println!(
                     "# Skipping {} due to FTBFS bugs ...",
                     outdated_package.source.package
