@@ -11,7 +11,10 @@ use std::{
 
 use anyhow::Result;
 use assorted_debian_utils::{
-    archive::MultiArch, package::PackageName, rfc822_like, version::PackageVersion,
+    archive::MultiArch,
+    package::{PackageName, VersionedPackage},
+    rfc822_like,
+    version::PackageVersion,
 };
 use indicatif::{ProgressBar, ProgressIterator};
 use serde::{
@@ -93,21 +96,22 @@ pub struct BinaryPackage {
 }
 
 impl BinaryPackage {
-    pub fn name_and_version(&self) -> (PackageName, PackageVersion) {
+    /// Obtain the package name and the source version (without binNMU version)
+    pub fn source_package(&self) -> VersionedPackage {
         if let Some(source_package) = &self.source {
-            (
-                source_package.source.clone(),
-                source_package
+            VersionedPackage {
+                package: source_package.source.clone(),
+                version: source_package
                     .version
                     .clone()
                     .unwrap_or_else(|| self.version.clone_without_binnmu_version()),
-            )
+            }
         } else {
             // no Source set, so Source == Package
-            (
-                self.package.clone(),
-                self.version.clone_without_binnmu_version(),
-            )
+            VersionedPackage {
+                package: self.package.clone(),
+                version: self.version.clone_without_binnmu_version(),
+            }
         }
     }
 }
@@ -139,7 +143,10 @@ impl SourcePackages {
         let mut all_sources = HashMap::<PackageName, SourcePackageInfo>::new();
         for path in paths {
             for binary_package in parse_packages::<BinaryPackage>(path.as_ref())? {
-                let (source, version) = binary_package.name_and_version();
+                let VersionedPackage {
+                    package: source,
+                    version,
+                } = binary_package.source_package();
 
                 if let Some(data) = all_sources.get_mut(&source) {
                     // store only highest version
@@ -195,7 +202,10 @@ impl SourcePackages {
 
         for path in paths {
             for binary_package in parse_packages::<BinaryPackage>(path.as_ref())? {
-                let (source, version) = binary_package.name_and_version();
+                let VersionedPackage {
+                    package: source,
+                    version,
+                } = binary_package.source_package();
 
                 if let Some(data) = all_sources.get_mut(&source) {
                     // store only highest version
@@ -260,3 +270,43 @@ where
     // collect all sources
     Ok(binary_packages.into_iter().progress_with(pb))
 }
+
+#[cfg(test)]
+mod test {
+    use super::*;
+
+    #[test]
+    fn binary_package() {
+        let package = rfc822_like::from_str::<BinaryPackage>(
+            "Package: binutils-m68hc1x
+Source: binutils-m68hc1x (1:3.5.3)
+Version: 1:2.44+3.5.3+b1
+Installed-Size: 15325
+Maintainer: Vincent Smeets <Vincent.VSmeets@gmail.com>
+Architecture: amd64
+Depends: libc6 (>= 2.38), libzstd1 (>= 1.5.5), zlib1g (>= 1:1.2.0), binutils-common
+Description: GNU binary utilities for Motorola's 68HC11/12 targets
+Multi-Arch: foreign
+Homepage: https://www.gnu.org/software/binutils/
+Built-Using: binutils (= 2.44-3)
+Description-md5: 7947f55c1400fe3dbfc4924951d4a7ad
+Tag: admin::hardware, devel::machinecode, hardware::embedded,
+ interface::commandline, role::program, scope::utility, suite::gnu
+Section: devel
+Priority: optional
+Filename: pool/main/b/binutils-m68hc1x/binutils-m68hc1x_2.44+3.5.3+b1_amd64.deb
+Size: 1921316
+MD5sum: a7f0e3faac69e6c9eace48ce1379b15a
+SHA256: 741c4058fc3cc23d697f6e4194e7fc8aef2d6d6628184e333316194c80bdbf17",
+        )
+        .unwrap();
+
+        assert_eq!(
+            package.source_package(),
+            VersionedPackage {
+                package: "binutils-m68hc1x".try_into().unwrap(),
+                version: "1:3.5.3".try_into().unwrap()
+            }
+        );
+    }
+}
